@@ -1,12 +1,12 @@
 package ExtUtils::Helpers::Unix;
 {
-  $ExtUtils::Helpers::Unix::VERSION = '0.013';
+  $ExtUtils::Helpers::Unix::VERSION = '0.014';
 }
 use strict;
 use warnings FATAL => 'all';
 
 use Exporter 5.57 'import';
-our @EXPORT = qw/make_executable split_like_shell detildefy/;
+our @EXPORT = qw/make_executable split_like_shell/;
 
 use Text::ParseWords 3.24 qw/shellwords/;
 use ExtUtils::MakeMaker;
@@ -29,16 +29,6 @@ sub split_like_shell {
   return shellwords($string);
 }
 
-sub detildefy {
-	my $value = shift;
-	# tilde with optional username
-	for ($value) {
-		s{ ^ ~ (?= /|$)}          [ $ENV{HOME} || (getpwuid $>)[7] ]ex or # tilde without user name
-		s{ ^ ~ ([^/]+) (?= /|$) } { (getpwnam $1)[7] || "~$1" }ex;        # tilde with user name
-	}
-	return $value;
-}
-
 1;
 
 # ABSTRACT: Unix specific helper bits
@@ -53,11 +43,10 @@ ExtUtils::Helpers::Unix - Unix specific helper bits
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =for Pod::Coverage make_executable
 split_like_shell
-detildefy
 
 =head1 AUTHORS
 
